@@ -164,11 +164,6 @@ from bitmovin_api_sdk.models.billable_encoding_minutes_details import BillableEn
 from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
 from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
 from bitmovin_api_sdk.models.bitmovin_response_list import BitmovinResponseList
-from bitmovin_api_sdk.models.bitmovin_stream_encoding_status import BitmovinStreamEncodingStatus
-from bitmovin_api_sdk.models.bitmovin_stream_encoding_task import BitmovinStreamEncodingTask
-from bitmovin_api_sdk.models.bitmovin_stream_quality import BitmovinStreamQuality
-from bitmovin_api_sdk.models.bitmovin_stream_response import BitmovinStreamResponse
-from bitmovin_api_sdk.models.bitmovin_stream_status import BitmovinStreamStatus
 from bitmovin_api_sdk.models.bitrate_selection_mode import BitrateSelectionMode
 from bitmovin_api_sdk.models.broadcast_ts_audio_input_stream_configuration import BroadcastTsAudioInputStreamConfiguration
 from bitmovin_api_sdk.models.broadcast_ts_input_stream_configuration import BroadcastTsInputStreamConfiguration
@@ -220,7 +215,6 @@ from bitmovin_api_sdk.models.content_protection import ContentProtection
 from bitmovin_api_sdk.models.convert_scc_caption import ConvertSccCaption
 from bitmovin_api_sdk.models.convert_scc_caption_web_vtt_settings import ConvertSccCaptionWebVttSettings
 from bitmovin_api_sdk.models.convert_scc_position_mode import ConvertSccPositionMode
-from bitmovin_api_sdk.models.create_bitmovin_stream_request import CreateBitmovinStreamRequest
 from bitmovin_api_sdk.models.crop_filter import CropFilter
 from bitmovin_api_sdk.models.custom_attribute import CustomAttribute
 from bitmovin_api_sdk.models.custom_data import CustomData
@@ -632,6 +626,7 @@ from bitmovin_api_sdk.models.simple_encoding_live_job_status import SimpleEncodi
 from bitmovin_api_sdk.models.simple_encoding_live_job_url_output import SimpleEncodingLiveJobUrlOutput
 from bitmovin_api_sdk.models.simple_encoding_live_job_username_password_credentials import SimpleEncodingLiveJobUsernamePasswordCredentials
 from bitmovin_api_sdk.models.simple_encoding_live_max_resolution import SimpleEncodingLiveMaxResolution
+from bitmovin_api_sdk.models.simple_encoding_live_profile import SimpleEncodingLiveProfile
 from bitmovin_api_sdk.models.simple_encoding_vod_job_access_key_credentials import SimpleEncodingVodJobAccessKeyCredentials
 from bitmovin_api_sdk.models.simple_encoding_vod_job_azure_credentials import SimpleEncodingVodJobAzureCredentials
 from bitmovin_api_sdk.models.simple_encoding_vod_job_cdn_output import SimpleEncodingVodJobCdnOutput
@@ -643,6 +638,7 @@ from bitmovin_api_sdk.models.simple_encoding_vod_job_input import SimpleEncoding
 from bitmovin_api_sdk.models.simple_encoding_vod_job_input_source_type import SimpleEncodingVodJobInputSourceType
 from bitmovin_api_sdk.models.simple_encoding_vod_job_input_type import SimpleEncodingVodJobInputType
 from bitmovin_api_sdk.models.simple_encoding_vod_job_output import SimpleEncodingVodJobOutput
+from bitmovin_api_sdk.models.simple_encoding_vod_job_output_artifact import SimpleEncodingVodJobOutputArtifact
 from bitmovin_api_sdk.models.simple_encoding_vod_job_output_type import SimpleEncodingVodJobOutputType
 from bitmovin_api_sdk.models.simple_encoding_vod_job_request import SimpleEncodingVodJobRequest
 from bitmovin_api_sdk.models.simple_encoding_vod_job_response import SimpleEncodingVodJobResponse
@@ -700,6 +696,14 @@ from bitmovin_api_sdk.models.stream_mode import StreamMode
 from bitmovin_api_sdk.models.stream_per_title_fixed_resolution_and_bitrate_settings import StreamPerTitleFixedResolutionAndBitrateSettings
 from bitmovin_api_sdk.models.stream_per_title_settings import StreamPerTitleSettings
 from bitmovin_api_sdk.models.stream_selection_mode import StreamSelectionMode
+from bitmovin_api_sdk.models.streams_live_update_request import StreamsLiveUpdateRequest
+from bitmovin_api_sdk.models.streams_video_create_request import StreamsVideoCreateRequest
+from bitmovin_api_sdk.models.streams_video_encoding_status import StreamsVideoEncodingStatus
+from bitmovin_api_sdk.models.streams_video_encoding_task import StreamsVideoEncodingTask
+from bitmovin_api_sdk.models.streams_video_quality import StreamsVideoQuality
+from bitmovin_api_sdk.models.streams_video_response import StreamsVideoResponse
+from bitmovin_api_sdk.models.streams_video_status import StreamsVideoStatus
+from bitmovin_api_sdk.models.streams_video_update_request import StreamsVideoUpdateRequest
 from bitmovin_api_sdk.models.subtask import Subtask
 from bitmovin_api_sdk.models.subtitle_adaptation_set import SubtitleAdaptationSet
 from bitmovin_api_sdk.models.subtitle_configuration import SubtitleConfiguration
@@ -732,7 +736,6 @@ from bitmovin_api_sdk.models.tu_inter_depth import TuInterDepth
 from bitmovin_api_sdk.models.tu_intra_depth import TuIntraDepth
 from bitmovin_api_sdk.models.tweaks import Tweaks
 from bitmovin_api_sdk.models.unsharp_filter import UnsharpFilter
-from bitmovin_api_sdk.models.update_bitmovin_stream_request import UpdateBitmovinStreamRequest
 from bitmovin_api_sdk.models.update_organization_request import UpdateOrganizationRequest
 from bitmovin_api_sdk.models.utc_timing import UtcTiming
 from bitmovin_api_sdk.models.variant_stream_dropping_mode import VariantStreamDroppingMode
